Documentation
¶
Index ¶
- type InternalVerification
- type ResponseConfirmVerification
- type ResponseSendToken
- type ResponseVerifyService
- func (s *ResponseVerifyService) InternalCompletePsd2Verification(to, code, amount, payee string) (*ResponseConfirmVerification, error)
- func (s *ResponseVerifyService) InternalCompleteVerification(to, code string) (*ResponseConfirmVerification, error)
- func (s *ResponseVerifyService) InternalStartPsd2Verification(to, channel, amount, payee string) (*ResponseSendToken, error)
- func (s *ResponseVerifyService) InternalStartVerification(to, channel string) (*ResponseSendToken, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type InternalVerification ¶
type InternalVerification interface {
InternalCompleteVerification(to, code string) (*ResponseConfirmVerification, error)
InternalStartVerification(to, channel string) (*ResponseSendToken, error)
InternalStartPsd2Verification(to, channel, amount, payee string) (*ResponseSendToken, error)
InternalCompletePsd2Verification(to, code, amount, payee string) (*ResponseConfirmVerification, error)
}
type ResponseConfirmVerification ¶
type ResponseConfirmVerification struct {
Sid string `json:"sid"`
ServiceSid string `json:"service_sid"`
AccountSid string `json:"account_sid"`
To string `json:"to"`
Channel string `json:"channel"`
Status string `json:"status"`
Valid bool `json:"valid"`
Amount interface{} `json:"amount"`
Payee interface{} `json:"payee"`
DateCreated time.Time `json:"date_created"`
DateUpdated time.Time `json:"date_updated"`
}
ResponseConfirmVerification is returned when a verification token is confirmed Successfully.
type ResponseSendToken ¶
type ResponseSendToken struct {
Sid string `json:"sid"`
ServiceSid string `json:"service_sid"`
AccountSid string `json:"account_sid"`
To string `json:"to"`
Channel string `json:"channel"`
Status string `json:"status"`
Valid bool `json:"valid"`
DateCreated time.Time `json:"date_created"`
DateUpdated time.Time `json:"date_updated"`
Lookup struct {
Carrier struct {
ErrorCode interface{} `json:"error_code"`
Name string `json:"name"`
MobileCountryCode string `json:"mobile_country_code"`
MobileNetworkCode string `json:"mobile_network_code"`
Type string `json:"type"`
} `json:"carrier"`
} `json:"lookup"`
Amount string `json:"amount"`
Payee string `json:"payee"`
SendCodeAttempts []struct {
Time time.Time `json:"time"`
Channel string `json:"channel"`
ChannelID interface{} `json:"channel_id"`
} `json:"send_code_attempts"`
URL string `json:"url"`
}
ResponseVerifyService is the Response model for the verification service creation.
type ResponseVerifyService struct {
Sid string `json:"sid"`
AccountSid string `json:"account_sid"`
FriendlyName string `json:"friendly_name"`
CodeLength int `json:"code_length"`
LookupEnabled bool `json:"lookup_enabled"`
Psd2Enabled bool `json:"psd2_enabled"`
SkipSmsToLandlines bool `json:"skip_sms_to_landlines"`
DtmfInputRequired bool `json:"dtmf_input_required"`
TtsName string `json:"tts_name"`
DoNotShareWarningEnabled bool `json:"do_not_share_warning_enabled"`
CustomCodeEnabled bool `json:"custom_code_enabled"`
Push struct {
IncludeDate bool `json:"include_date"`
ApnCredentialSid string `json:"apn_credential_sid"`
FcmCredentialSid interface{} `json:"fcm_credential_sid"`
} `json:"push"`
DateCreated time.Time `json:"date_created"`
DateUpdated time.Time `json:"date_updated"`
URL string `json:"url"`
Links struct {
VerificationChecks string `json:"verification_checks"`
Verifications string `json:"verifications"`
RateLimits string `json:"rate_limits"`
MessagingConfigurations string `json:"messaging_configurations"`
Entities string `json:"entities"`
Webhooks string `json:"webhooks"`
AccessTokens string `json:"access_tokens"`
} `json:"links"`
}
ResponseSendToken is returned when a verification token is sent too a user.
type ResponseVerifyService ¶
type ResponseVerifyService struct {
Client app.InternalAuth
Sid string `json:"sid"`
AccountSid string `json:"account_sid"`
FriendlyName string `json:"friendly_name"`
CodeLength int `json:"code_length"`
LookupEnabled bool `json:"lookup_enabled"`
Psd2Enabled bool `json:"psd2_enabled"`
SkipSmsToLandlines bool `json:"skip_sms_to_landlines"`
DtmfInputRequired bool `json:"dtmf_input_required"`
TtsName string `json:"tts_name"`
CustomCodeEnabled bool `json:"custom_code_enabled"`
Push struct {
IncludeDate bool `json:"include_date"`
ApnCredentialSid string `json:"apn_credential_sid"`
FcmCredentialSid interface{} `json:"fcm_credential_sid"`
} `json:"push"`
DateCreated time.Time `json:"date_created"`
DateUpdated time.Time `json:"date_updated"`
URL string `json:"url"`
Links struct {
VerificationChecks string `json:"verification_checks"`
Verifications string `json:"verifications"`
RateLimits string `json:"rate_limits"`
MessagingConfigurations string `json:"messaging_configurations"`
Entities string `json:"entities"`
Webhooks string `json:"webhooks"`
AccessTokens string `json:"access_tokens"`
} `json:"links"`
}
func (*ResponseVerifyService) InternalCompletePsd2Verification ¶
func (s *ResponseVerifyService) InternalCompletePsd2Verification(to, code, amount, payee string) (*ResponseConfirmVerification, error)
func (*ResponseVerifyService) InternalCompleteVerification ¶
func (s *ResponseVerifyService) InternalCompleteVerification(to, code string) (*ResponseConfirmVerification, error)
func (*ResponseVerifyService) InternalStartPsd2Verification ¶
func (s *ResponseVerifyService) InternalStartPsd2Verification(to, channel, amount, payee string) (*ResponseSendToken, error)
func (*ResponseVerifyService) InternalStartVerification ¶
func (s *ResponseVerifyService) InternalStartVerification(to, channel string) (*ResponseSendToken, error)
Click to show internal directories.
Click to hide internal directories.